@@ -19,6 +19,7 @@ import json
 from babel.core import Locale
 from babel.messages.catalog import Catalog as BabelCatalog
 
+from django.conf import settings
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
@@ -28,6 +29,7 @@ class Project(models.Model):
     """
     name = models.CharField(_('name'), max_length=150)
     slug = models.SlugField(_('slug'), unique=True, max_length=75)
+    domain = models.CharField(_('translation domain'), choices=settings.GETTEXT_DOMAINS, default=settings.DEFAULT_GETTEXT_DOMAINS, max_length=20)
     description = models.TextField(_('description'), blank=True)
 
     def __unicode__(self):
@@ -56,6 +58,7 @@ class ProjectVersion(models.Model):
         forged_catalog = BabelCatalog(
             header_comment=self.header_comment,
             project=self.project.name,
+            domain=self.project.domain,
             version=str(self.version)
         )
         
@@ -128,18 +131,35 @@ class Catalog(models.Model):
         """Return a count of translations with message marked as fuzzy"""
         return self.translationmsg_set.filter(fuzzy=True).count()
 
-    def get_babel_catalog(self):
+    def get_progress(self):
+        """
+        Return a percentage of progress (all filled item that are not fuzzy)
+        """
+        total = self.translationmsg_set.all().count()
+        filled = self.translationmsg_set.exclude(message="").exclude(fuzzy=True).count()
+        return (filled*100)/total
+
+    def get_babel_catalog(self, solid=False):
         """
         Return a babel catalog suitable for a PO file
+        
+        ``solid`` argument is a boolean to define if the catalog also store empty and 
+        fuzzy translation item (True) or drop them (False)
         """
         forged_catalog = BabelCatalog(
             locale=self.locale, 
             header_comment=self.header_comment,
             project=self.project_version.project.name,
+            domain=self.project_version.project.domain,
             version=str(self.project_version.version)
         )
         
-        for entry in self.translationmsg_set.all().order_by('id'):
+        queryset = self.translationmsg_set.all()
+        # Exclude empty and fuzzy from queryset
+        if solid:
+            queryset = queryset.exclude(message="").exclude(fuzzy=True)
+        # Fill a Babel catalog from translation items
+        for entry in queryset.order_by('id'):
             locations = [tuple(item) for item in json.loads(entry.template.locations)]
             forged_catalog.add(entry.template.message, string=entry.message, locations=locations, flags=entry.get_flags())
         
