@@ -11,7 +11,7 @@ from rest_framework import status, viewsets, generics, renderers
 from rest_framework.decorators import api_view
 from rest_framework.reverse import reverse
 
-from po_projects.models import Project, ProjectVersion, TemplateMsg, Catalog, TranslationMsg
+from po_projects.models import Project, ProjectVersion
 from po_projects.rest.serializers import ProjectCurrentSerializer, ProjectVersionSerializer
 from po_projects.mixins import DownloadMixin
 from po_projects.dump import po_project_export
@@ -57,8 +57,6 @@ class ProjectCurrentDetail(ProjectDetailMixin, generics.RetrieveUpdateAPIView):
     
     ``projectversion_set`` urls use the version ID (pk), not the slug or version name.
     
-    The view behind the tarball url accept one optionnal url argument ``kind`` that can be ``django`` or ``messages``, this will change the filename of the catalog files, because commonly with gettext the catalog file is named ``messages.po`` and with Django the catalog file is named ``django.po``. Default if not defined is to use the value from ``settings.DEFAULT_CATALOG_FILENAMES``.
-    
     This view is a "Retrieve and update" view, so you can see and get project details 
     but also update its content.
     
@@ -88,8 +86,6 @@ class ProjectVersionDetail(APIView):
 class ProjectArchive(ProjectDetailMixin, DownloadMixin, APIView):
     """
     Send a ZIP archive for the project's PO files
-    
-    TODO: share code from a mixin using code from ProjectExportView
     """
     content_type = 'application/x-gzip'
     filename_format = "{project_slug}_{timestamp}.tar.gz"
@@ -98,12 +94,6 @@ class ProjectArchive(ProjectDetailMixin, DownloadMixin, APIView):
         self.object = self.get_object()
         return super(ProjectArchive, self).get(request)
 
-    def get_catalog_kind(self):
-        kind = self.request.GET.get('kind', settings.DEFAULT_CATALOG_FILENAMES)
-        if kind not in settings.AVAILABLE_CATALOG_FILENAMES:
-            return settings.DEFAULT_CATALOG_FILENAMES
-        return kind
-
     def get_context_data(self, **kwargs):
         context = super(ProjectArchive, self).get_context_data(**kwargs)
         context.update({
@@ -119,6 +109,6 @@ class ProjectArchive(ProjectDetailMixin, DownloadMixin, APIView):
     def get_content(self, context):
         archive_file = StringIO()
         
-        po_project_export(self.object, self.object.get_current_version(), archive_file, catalog_filename=self.get_catalog_kind())
+        po_project_export(self.object, self.object.get_current_version(), archive_file)
         
         return archive_file.getvalue()
